'use strict';

angular.module('main', [
  'ionic',
  'ngCordova',
  'ui.router',
  'uiGmapgoogle-maps',
])

.config(function ($stateProvider, $urlRouterProvider) {

  $stateProvider.state('main', {
    abstract: true,
    url: '/main',
    templateUrl: 'main/templates/main.html',
    controller: 'MainCtrl'
  });

  $stateProvider.state('main.info', {
    url: '/info',
    views: {
      info: {
        templateUrl: 'main/templates/info.html'
      }
    }
  });

  $stateProvider.state('main.news', {
    url: '/news',
    views: {
      news: {
        templateUrl: 'main/templates/news.html',
        controller: 'NewsCtrl',
      }
    }
  });

  $stateProvider.state('main.add', {
    url: '/add',
    views: {
      add: {
        templateUrl: 'main/templates/add.html',
        controller: 'AddCtrl',
      }
    }
  });

  $stateProvider.state('main.map', {
    abstract: true,
    url: '/map',
    views: {
      map: {
        template: '<ion-nav-view></ion-nav-view>'
      }
    }
  });

  $stateProvider.state('main.map.index', {
    url: '',
    templateUrl: 'main/templates/map.html',
    controller: 'MapCtrl'
  });

  $stateProvider.state('main.map.detail', {
    url: '/:location',
    templateUrl: 'main/templates/detail.html',
    controller: 'DetailCtrl',
    resolve: {
      location: function ($stateParams, MapService) {
        var loc = MapService.getLocation($stateParams.location);
        return loc;
      }
    }
  });

  $stateProvider.state('main.list', {
    abstract: true,
    url: '/list',
    views: {
      list: {
        template: '<ion-nav-view></ion-nav-view>'
      }
    }
  });

  $stateProvider.state('main.list.index', {
    url: '',
    templateUrl: 'main/templates/list.html',
    controller: 'ListCtrl'
  });

  $stateProvider.state('main.list.detail', {
    url: '/:location',
    templateUrl: 'main/templates/detail.html',
    controller: 'DetailCtrl',
    resolve: {
      location: function ($stateParams, MapService) {
        var loc = MapService.getLocation($stateParams.location);
        return loc;
      }
    }
  });

  $urlRouterProvider.otherwise('/main/info');

});

'use strict';

angular.module('main')
  .factory('ParseService', function ($q) {
    var states = {
      'AGS': 'Aguascalientes',
      'BCN': 'Baja California',
      'BCS': 'Baja California Sur',
      'CAM': 'Campeche',
      'CHP': 'Chiapas',
      'CHI': 'Chihuahua',
      'COA': 'Coahuila',
      'COL': 'Colima',
      'DIF': 'Distrito Federal',
      'DUR': 'Durango',
      'GTO': 'Guanajuato',
      'GRO': 'Guerrero',
      'HGO': 'Hidalgo',
      'JAL': 'Jalisco',
      'MEX': 'Estado de México',
      'MIC': 'Michoacán',
      'MOR': 'Morelos',
      'NAY': 'Nayarit',
      'NLE': 'Nuevo León',
      'OAX': 'Oaxaca',
      'PUE': 'Puebla',
      'QRO': 'Querétaro',
      'ROO': 'Quintana Roo',
      'SLP': 'San Luis Potosí',
      'SIN': 'Sinaloa',
      'SON': 'Sonora',
      'TAB': 'Tabasco',
      'TAM': 'Tamaulipas',
      'TLX': 'Tlaxcala',
      'VER': 'Veracruz',
      'YUC': 'Yucatán',
      'ZAC': 'Zacatecas'
    };
    var promise;

    return {
      addUbicacion: function (form) {
        var Ubicacion = Parse.Object.extend('Ubicacion');
        var ubicacion = new Ubicacion();

        ubicacion.set('nombre', form.nombre);

        var TipoUbicacion = Parse.Object.extend('TipoUbicacion');
        var tipoUbicacion = new TipoUbicacion();
        tipoUbicacion.id = form.tipo;
        ubicacion.set('tipo', tipoUbicacion);

        if (form.localizacion) {
          var coordenadas = new Parse.GeoPoint ({
            latitude: form.latitud,
            longitude: form.longitud
          });
          ubicacion.set('coordenadas', coordenadas);
        }

        if (form.telefono) {
          ubicacion.set('telefono', form.telefono);
        }

        if (form.direccion) {
          ubicacion.set('direccion', form.direccion);
        }

        ubicacion.set('publicada', false);

        var promise = ubicacion.save().then(function (ubicacion) {
          return ubicacion;
        }, function (response) {
          return $q.reject(response);
        });
        return promise;
      },

      getTipos: function () {
        if (!promise) {
          var TipoUbicacion = Parse.Object.extend('TipoUbicacion');
          promise = new Parse.Query(TipoUbicacion).find().then(function (tipos) {
            return tipos;
          }, function (response) {
            return $q.reject(response);
          });
        }
        return promise;
      },

      getNoticias: function () {
        if (!promise) {
          var Noticia = Parse.Object.extend('Noticia');
          promise = new Parse.Query(Noticia).descending('createdAt').find().then(function (noticias) {
            return noticias;
          }, function (response) {
            return $q.reject(response);
          });
        }
        return promise;
      },

      getStateName: function (abr) {
        return states[abr];
      }
    };
  });

'use strict';

angular.module('main')
  .factory('MapService', function ($q, $filter) {

    var stationMarker  = 'main/assets/images/gas_marker.png';
    var serviceMarker = 'main/assets/images/lovato_marker.png';

    var locations = [];
    var promise;

    return {
      getLocations: function (userLocation) {
        if (!promise) {
          var userGeoPoint = new Parse.GeoPoint ({
            latitude: userLocation.lat,
            longitude: userLocation.lng
          });

          var query = new Parse.Query(Parse.Object.extend('Ubicacion'));

          promise = query.limit(1000).include('tipo').equalTo('publicada', true).ascending('estado')
            .find().then(function (foundLocations) {
              angular.forEach(foundLocations, function (location, key) {
                locations.push({
                  'id': key + 1,
                  'title': location.get('nombre'),
                  'type': location.get('tipo').get('nombre'),
                  'image': location.get('imagen') ? location.get('imagen').url() : '',
                  'latitude': location.get('coordenadas').latitude,
                  'longitude': location.get('coordenadas').longitude,
                  'distance': location.get('coordenadas').kilometersTo(userGeoPoint),
                  'state': location.get('estado'),
                  'address': location.get('direccion') ? location.get('direccion') : '',
                  'telephone': location.get('telefono') ? location.get('telefono') : '',
                  'icon': location.get('tipo').get('nombre').indexOf('Distribuidor') > -1 ? serviceMarker : stationMarker
                });
              });
              return locations;
            }, function (response) {
              return $q.reject(response);
            });
        }
        return promise;
      },

      getLocation: function (id) {
        var found = $filter('filter')(locations, {'id': id});
        return found[0];
      },

      getLocationList: function () {
        var newArr = [], states = {}, i, j, cur;
        for (i = 0, j = locations.length; i < j; i++) {
          cur = locations[i];
          if (!(cur.state in states)) {
            states[cur.state] = {state: cur.state, locations: []};
            newArr.push(states[cur.state]);
          }
          states[cur.state].locations.push(cur);
        }

        console.log(newArr);
        return newArr;
      }

    };
  });

'use strict';

angular.module('main')
  .filter('groupByState', function (ParseService) {
    var dividers = {};

    return function (input) {
      if (!input || !input.length) {
        return;
      }

      var output = [], previousState, currentState;

      for (var i = 0, ii = input.length; i < ii; i++) {
        currentState = ParseService.getStateName(input[i].state);
        if (!previousState || currentState !== previousState) {
          var dividerId = currentState;

          if (!dividers[dividerId]) {
            dividers[dividerId] = {
              isDivider: true,
              divider: currentState
            };
          }

          output.push(dividers[dividerId]);
        }

        output.push(input[i]);
        previousState = currentState;
      }

      return output;
    };
  });

'use strict';

angular.module('main')
  .directive('dividerCollectionRepeat', function () {
    function compile (element, attr) {
      var height = '70';
      attr.$set('itemHeight', 'item.isDivider ? 37 : ' + height);

      element.children().attr('ng-hide', 'item.isDivider');
      element.prepend(
        '<div class="item item-divider ng-hide" ng-show="item.isDivider" ng-bind="item.divider"></div>'
      );
    }

    return {
      priority: 1001,
      compile: compile
    };
  });

'use strict';

angular.module('main')
  .controller('NewsCtrl', function ($scope, ParseService) {
    $scope.news = [];

    ParseService.getNoticias().then(
      function (noticias) {
        $scope.$apply(function () {
          angular.forEach(noticias, function (noticia) {
            $scope.news.push({
              texto: noticia.get('texto'),
              fecha: noticia.createdAt
            });
          });
        });
      });

  });

'use strict';

angular.module('main')
  .controller('MapCtrl', function ($scope, $rootScope, $state, MapService) {

    $scope.onClick = function (instance, event, marker) {
      if (marker.id > 0) {
        $state.go('main.map.detail', {'location': marker.id});
      }
    };

    $scope.markers = [];

    $scope.map = {
      center: {
        latitude: $rootScope.myLocation.lat,
        longitude: $rootScope.myLocation.lng
      },
      zoom: 12,
      pan: 1
    };

    $scope.markers.push({
      'id': 0,
      'latitude': $rootScope.myLocation.lat,
      'longitude': $rootScope.myLocation.lng,
      'icon': 'main/assets/images/location_marker.png'
    });

    MapService.getLocations($rootScope.myLocation).then(
      function (locations) {
        angular.forEach(locations, function (location) {
          $scope.markers.push(location);
        });
      });

  });

'use strict';

angular.module('main')
  .controller('MainCtrl', function ($rootScope, $ionicPlatform, MapService) {

    $ionicPlatform.ready(function () {
      Parse.initialize('nXzeOmAa5NbdL8BRS0g1QO8wzDboHbjE9XEHu66a', 'sK7xl5Pdd9JEfWcpOdRk2g3f1zwaHVmlU4eg8KCR');
    });

    navigator.geolocation.getCurrentPosition(function (position) {
      $rootScope.myLocation = {
        lng: position.coords.longitude,
        lat: position.coords.latitude
      };

      MapService.getLocations($rootScope.myLocation);
    });
  });

'use strict';

angular.module('main')
  .controller('ListCtrl', function ($scope, $rootScope, MapService) {
    $scope.sel = 0;
    $scope.locations = [];
    $scope.dist = [];

    MapService.getLocations($rootScope.myLocation).then(
      function (locations) {
        angular.forEach(locations, function (location) {
          if (location.type.indexOf('Distribuidor') > -1) {
            $scope.dist.push(location);
          } else {
            $scope.locations.push(location);
          }
        });
      });

  });

'use strict';

angular.module('main')
  .controller('DetailCtrl', function ($scope, $rootScope, location) {
    $scope.location = location;

    var dirRenderer = new google.maps.DirectionsRenderer({preserveViewport: true});
    var directionsDisplay = new google.maps.DirectionsRenderer(dirRenderer);
    var directionsService = new google.maps.DirectionsService();

    var request = {
      origin: $rootScope.myLocation.lat + ',' + $rootScope.myLocation.lng,
      destination: location.latitude + ',' + location.longitude,
      travelMode: google.maps.DirectionsTravelMode.DRIVING
    };

    $scope.map = {
      zoom: 12,
      center: {
        latitude: $rootScope.myLocation.lat,
        longitude: $rootScope.myLocation.lng
      },
      options: {
        draggable: true
      },
      events: {
        tilesloaded: function (map) {
          $scope.$apply(function () {
            directionsService.route(request, function (response, status) {
              if (status === google.maps.DirectionsStatus.OK) {
                directionsDisplay.setDirections(response);
                directionsDisplay.setMap(map);
              }
            });
          });
        }
      }
    };
  });

'use strict';

angular.module('main')
  .controller('AddCtrl', function ($rootScope, $scope, ParseService) {

    $scope.ubicacion = {
      nombre: '',
      tipo: '0',
      direccion: '',
      telefono: '',
      localizacion: true
    };
    $scope.forma = {
      enviada: false,
      resultado: '',
      mensaje: ''
    };
    $scope.tipos = [];

    ParseService.getTipos().then(
      function (tipos) {
        angular.forEach(tipos, function (tipo) {
          $scope.tipos.push({
            'value': tipo.id,
            'label': tipo.get('nombre')
          });
        });
      });

    $scope.add = function () {
      if ($scope.ubicacion.tipo !== '0' && $scope.ubicacion.nombre && $scope.ubicacion.direccion) {
        $scope.forma.enviada = true;

        if ($scope.ubicacion.localizacion) {
          $scope.ubicacion.latitud = $rootScope.myLocation.lat;
          $scope.ubicacion.longitud = $rootScope.myLocation.lng;
        }

        ParseService.addUbicacion($scope.ubicacion).then(
          function (ubicacion) {
            if (ubicacion && (ubicacion.id || ubicacion.objectId)) {
              $scope.forma.resultado = 'success';
              $scope.forma.mensaje = 'La ubicación fue enviada exitosamente. Gracias por tu participación.';
            } else {
              $scope.forma.resultado = 'error';
              $scope.forma.mensaje = 'Ocurrió un error al enviar la ubicación. Inténtalo más tarde.';
            }
          });
      } else {
        $scope.forma.resultado = 'error';
        $scope.forma.mensaje = 'Ingresa los datos obligatorios marcados con un asterisco.';
      }
    };

  });


'use strict';

angular.module('appTocasa', [
  'main'
])

.config(function ($ionicConfigProvider) {
  $ionicConfigProvider.navBar.alignTitle('center');
  $ionicConfigProvider.tabs.position('bottom');
  $ionicConfigProvider.tabs.style('default');
});
